@@ -1,7 +1,7 @@
 package Org::To::HTML;
 
-our $DATE = '2015-08-18'; # DATE
-our $VERSION = '0.15'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.16'; # VERSION
 
 use 5.010;
 use Log::Any::IfLOG '$log';
@@ -392,7 +392,7 @@ Org::To::HTML - Export Org document to HTML
 
 =head1 VERSION
 
-This document describes version 0.15 of Org::To::HTML (from Perl distribution Org-To-HTML), released on 2015-08-18.
+This document describes version 0.16 of Org::To::HTML (from Perl distribution Org-To-HTML), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -425,12 +425,10 @@ A command-line utility is included: L<org-to-html>.
 
 =head2 org_to_html(%args) -> [status, msg, result, meta]
 
-{en_US Export Org document to HTML}.
+Export Org document to HTML.
 
-{en_US 
 This is the non-OO interface. For more customization, consider subclassing
 Org::To::HTML.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -438,56 +436,50 @@ Arguments ('*' denotes required arguments):
 
 =item * B<css_url> => I<str>
 
-{en_US Add a link to CSS document}.
+Add a link to CSS document.
 
 =item * B<exclude_tags> => I<array[str]>
 
-{en_US Exclude trees that carry one of these tags}.
+Exclude trees that carry one of these tags.
 
-{en_US 
 If the whole document doesn't have any of these tags, then the whole document
 will be exported. Otherwise, trees that do not carry one of these tags will be
 excluded. If a selected tree is a subtree, the heading hierarchy above it will
 also be selected for export, but not the text below those headings.
 
 exclude_tags is evaluated after include_tags.
-}
 
 =item * B<html_title> => I<str>
 
-{en_US HTML document title, defaults to source_file}.
+HTML document title, defaults to source_file.
 
 =item * B<include_tags> => I<array[str]>
 
-{en_US Include trees that carry one of these tags}.
+Include trees that carry one of these tags.
 
-{en_US 
 Works like Org's 'org-export-select-tags' variable. If the whole document
 doesn't have any of these tags, then the whole document will be exported.
 Otherwise, trees that do not carry one of these tags will be excluded. If a
 selected tree is a subtree, the heading hierarchy above it will also be selected
 for export, but not the text below those headings.
-}
 
 =item * B<naked> => I<bool>
 
-{en_US Don't wrap exported HTML with HTML/HEAD/BODY elements}.
+Don't wrap exported HTML with HTML/HEAD/BODY elements.
 
 =item * B<source_file> => I<str>
 
-{en_US Source Org file to export}.
+Source Org file to export.
 
 =item * B<source_str> => I<str>
 
-{en_US Alternatively you can specify Org string directly}.
+Alternatively you can specify Org string directly.
 
 =item * B<target_file> => I<str>
 
-{en_US HTML file to write to}.
+HTML file to write to.
 
-{en_US 
 If not specified, HTML string will be returned.
-}
 
 =back
 
